==> DateTime-Locale-1.32.tar.gz: DateTime-Locale-1.32/share/yue-Hans-CN.pl <==
{
  am_pm_abbreviated => [
    "\N{U+4e0a}\N{U+5348}",
    "\N{U+4e0b}\N{U+5348}",
  ],
  available_formats => {
    Bh => "Bh\N{U+65f6}",
    Bhm => "Bh:mm",
    Bhms => "Bh:mm:ss",
    E => "ccc",
    EBhm => "E Bh:mm",
    EBhms => "E Bh:mm:ss",
    EHm => "EHH:mm",
    EHms => "EHH:mm:ss",
    Ed => "d\N{U+65e5}E",
    Ehm => "Eah:mm",
    Ehms => "Eah:mm:ss",
    Gy => "Gy\N{U+5e74}",
    GyMMM => "Gy\N{U+5e74}M\N{U+6708}",
    GyMMMEd => "Gy\N{U+5e74}M\N{U+6708}d\N{U+65e5}E",
    GyMMMd => "Gy\N{U+5e74}M\N{U+6708}d\N{U+65e5}",
    H => "H\N{U+65f6}",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "v HH:mm:ss",
    Hmv => "v HH:mm",
    M => "M\N{U+6708}",
    MEd => "M/dE",
    MMM => "LLL",
    MMMEd => "M\N{U+6708}d\N{U+65e5}E",
    "MMMMW-count-other" => "M\N{U+6708}\N{U+7b2c}W\N{U+4e2a}\N{U+661f}\N{U+671f}",
    MMMMd => "M\N{U+6708}d\N{U+65e5}",
    MMMd => "M\N{U+6708}d\N{U+65e5}",
    MMdd => "MM/dd",
    Md => "M/d",
    d => "d\N{U+65e5}",
    h => "ah\N{U+65f6}",
    hm => "ah:mm",
    hms => "ah:mm:ss",
    hmsv => "v ah:mm:ss",
    hmv => "v ah:mm",
    ms => "mm:ss",
    y => "y\N{U+5e74}",
    yM => "y\N{U+5e74}M\N{U+6708}",
    yMEd => "y/M/dE",
    yMM => "y\N{U+5e74}M\N{U+6708}",
    yMMM => "y\N{U+5e74}M\N{U+6708}",
    yMMMEd => "y\N{U+5e74}M\N{U+6708}d\N{U+65e5}E",
    yMMMM => "y\N{U+5e74}M\N{U+6708}",
    yMMMd => "y\N{U+5e74}M\N{U+6708}d\N{U+65e5}",
    yMd => "y/M/d",
    yQQQ => "y\N{U+5e74}QQQ",
    yQQQQ => "y\N{U+5e74}QQQQ",
    "yw-count-other" => "Y\N{U+5e74}\N{U+7b2c}w\N{U+4e2a}\N{U+661f}\N{U+671f}",
  },
  code => "yue-Hans-CN",
  date_format_full => "y\N{U+5e74}M\N{U+6708}d\N{U+65e5}EEEE",
  date_format_long => "y\N{U+5e74}M\N{U+6708}d\N{U+65e5}",
  date_format_medium => "y\N{U+5e74}M\N{U+6708}d\N{U+65e5}",
  date_format_short => "y/M/d",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "\N{U+5468}\N{U+4e00}",
    "\N{U+5468}\N{U+4e8c}",
    "\N{U+5468}\N{U+4e09}",
    "\N{U+5468}\N{U+56db}",
    "\N{U+5468}\N{U+4e94}",
    "\N{U+5468}\N{U+516d}",
    "\N{U+5468}\N{U+65e5}",
  ],
  day_format_narrow => [
    "\N{U+4e00}",
    "\N{U+4e8c}",
    "\N{U+4e09}",
    "\N{U+56db}",
    "\N{U+4e94}",
    "\N{U+516d}",
    "\N{U+65e5}",
  ],
  day_format_wide => [
    "\N{U+661f}\N{U+671f}\N{U+4e00}",
    "\N{U+661f}\N{U+671f}\N{U+4e8c}",
    "\N{U+661f}\N{U+671f}\N{U+4e09}",
    "\N{U+661f}\N{U+671f}\N{U+56db}",
    "\N{U+661f}\N{U+671f}\N{U+4e94}",
    "\N{U+661f}\N{U+671f}\N{U+516d}",
    "\N{U+661f}\N{U+671f}\N{U+65e5}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+5468}\N{U+4e00}",
    "\N{U+5468}\N{U+4e8c}",
    "\N{U+5468}\N{U+4e09}",
    "\N{U+5468}\N{U+56db}",
    "\N{U+5468}\N{U+4e94}",
    "\N{U+5468}\N{U+516d}",
    "\N{U+5468}\N{U+65e5}",
  ],
  day_stand_alone_narrow => [
    "\N{U+4e00}",
    "\N{U+4e8c}",
    "\N{U+4e09}",
    "\N{U+56db}",
    "\N{U+4e94}",
    "\N{U+516d}",
    "\N{U+65e5}",
  ],
  day_stand_alone_wide => [
    "\N{U+661f}\N{U+671f}\N{U+4e00}",
    "\N{U+661f}\N{U+671f}\N{U+4e8c}",
    "\N{U+661f}\N{U+671f}\N{U+4e09}",
    "\N{U+661f}\N{U+671f}\N{U+56db}",
    "\N{U+661f}\N{U+671f}\N{U+4e94}",
    "\N{U+661f}\N{U+671f}\N{U+516d}",
    "\N{U+661f}\N{U+671f}\N{U+65e5}",
  ],
  era_abbreviated => [
    "\N{U+897f}\N{U+5143}\N{U+524d}",
    "\N{U+897f}\N{U+5143}",
  ],
  era_narrow => [
    "\N{U+897f}\N{U+5143}\N{U+524d}",
    "\N{U+897f}\N{U+5143}",
  ],
  era_wide => [
    "\N{U+897f}\N{U+5143}\N{U+524d}",
    "\N{U+897f}\N{U+5143}",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Cantonese",
  month_format_abbreviated => [
    "1\N{U+6708}",
    "2\N{U+6708}",
    "3\N{U+6708}",
    "4\N{U+6708}",
    "5\N{U+6708}",
    "6\N{U+6708}",
    "7\N{U+6708}",
    "8\N{U+6708}",
    "9\N{U+6708}",
    "10\N{U+6708}",
    "11\N{U+6708}",
    "12\N{U+6708}",
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_format_wide => [
    "\N{U+4e00}\N{U+6708}",
    "\N{U+4e8c}\N{U+6708}",
    "\N{U+4e09}\N{U+6708}",
    "\N{U+56db}\N{U+6708}",
    "\N{U+4e94}\N{U+6708}",
    "\N{U+516d}\N{U+6708}",
    "\N{U+4e03}\N{U+6708}",
    "\N{U+516b}\N{U+6708}",
    "\N{U+4e5d}\N{U+6708}",
    "\N{U+5341}\N{U+6708}",
    "\N{U+5341}\N{U+4e00}\N{U+6708}",
    "\N{U+5341}\N{U+4e8c}\N{U+6708}",
  ],
  month_stand_alone_abbreviated => [
    "1\N{U+6708}",
    "2\N{U+6708}",
    "3\N{U+6708}",
    "4\N{U+6708}",
    "5\N{U+6708}",
    "6\N{U+6708}",
    "7\N{U+6708}",
    "8\N{U+6708}",
    "9\N{U+6708}",
    "10\N{U+6708}",
    "11\N{U+6708}",
    "12\N{U+6708}",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "\N{U+4e00}\N{U+6708}",
    "\N{U+4e8c}\N{U+6708}",
    "\N{U+4e09}\N{U+6708}",
    "\N{U+56db}\N{U+6708}",
    "\N{U+4e94}\N{U+6708}",
    "\N{U+516d}\N{U+6708}",
    "\N{U+4e03}\N{U+6708}",
    "\N{U+516b}\N{U+6708}",
    "\N{U+4e5d}\N{U+6708}",
    "\N{U+5341}\N{U+6708}",
    "\N{U+5341}\N{U+4e00}\N{U+6708}",
    "\N{U+5341}\N{U+4e8c}\N{U+6708}",
  ],
  name => "Cantonese China Simplified",
  native_language => "\N{U+7ca4}\N{U+8bed}",
  native_name => "\N{U+7ca4}\N{U+8bed} \N{U+4e2d}\N{U+534e}\N{U+4eba}\N{U+6c11}\N{U+5171}\N{U+548c}\N{U+56fd} \N{U+7b80}\N{U+4f53}",
  native_script => "\N{U+7b80}\N{U+4f53}",
  native_territory => "\N{U+4e2d}\N{U+534e}\N{U+4eba}\N{U+6c11}\N{U+5171}\N{U+548c}\N{U+56fd}",
  native_variant => undef,
  quarter_format_abbreviated => [
    "\N{U+7b2c}1\N{U+5b63}",
    "\N{U+7b2c}2\N{U+5b63}",
    "\N{U+7b2c}3\N{U+5b63}",
    "\N{U+7b2c}4\N{U+5b63}",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "\N{U+7b2c}1\N{U+5b63}",
    "\N{U+7b2c}2\N{U+5b63}",
    "\N{U+7b2c}3\N{U+5b63}",
    "\N{U+7b2c}4\N{U+5b63}",
  ],
  quarter_stand_alone_abbreviated => [
    "\N{U+7b2c}1\N{U+5b63}",
    "\N{U+7b2c}2\N{U+5b63}",
    "\N{U+7b2c}3\N{U+5b63}",
    "\N{U+7b2c}4\N{U+5b63}",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "\N{U+7b2c}1\N{U+5b63}",
    "\N{U+7b2c}2\N{U+5b63}",
    "\N{U+7b2c}3\N{U+5b63}",
    "\N{U+7b2c}4\N{U+5b63}",
  ],
  script => "Simplified",
  territory => "China",
  time_format_full => "zzzz ah:mm:ss",
  time_format_long => "z ah:mm:ss",
  time_format_medium => "ah:mm:ss",
  time_format_short => "ah:mm",
  variant => undef,
  version => 39,
}

==> DateTime-Locale-1.33.tar.gz: DateTime-Locale-1.33/share/yue-Hans-CN.pl <==
{
  am_pm_abbreviated => [
    "\N{U+4e0a}\N{U+5348}",
    "\N{U+4e0b}\N{U+5348}",
  ],
  available_formats => {
    Bh => "Bh\N{U+65f6}",
    Bhm => "Bh:mm",
    Bhms => "Bh:mm:ss",
    E => "ccc",
    EBhm => "E Bh:mm",
    EBhms => "E Bh:mm:ss",
    EHm => "EHH:mm",
    EHms => "EHH:mm:ss",
    Ed => "d\N{U+65e5}E",
    Ehm => "Eah:mm",
    Ehms => "Eah:mm:ss",
    Gy => "Gy\N{U+5e74}",
    GyMMM => "Gy\N{U+5e74}M\N{U+6708}",
    GyMMMEd => "Gy\N{U+5e74}M\N{U+6708}d\N{U+65e5}E",
    GyMMMd => "Gy\N{U+5e74}M\N{U+6708}d\N{U+65e5}",
    GyMd => "GGGGG y-MM-dd",
    H => "H\N{U+65f6}",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "v HH:mm:ss",
    Hmv => "v HH:mm",
    M => "M\N{U+6708}",
    MEd => "M/dE",
    MMM => "LLL",
    MMMEd => "M\N{U+6708}d\N{U+65e5}E",
    "MMMMW-count-other" => "M\N{U+6708}\N{U+7b2c}W\N{U+4e2a}\N{U+661f}\N{U+671f}",
    MMMMd => "M\N{U+6708}d\N{U+65e5}",
    MMMd => "M\N{U+6708}d\N{U+65e5}",
    MMdd => "MM/dd",
    Md => "M/d",
    d => "d\N{U+65e5}",
    h => "ah\N{U+65f6}",
    hm => "ah:mm",
    hms => "ah:mm:ss",
    hmsv => "v ah:mm:ss",
    hmv => "v ah:mm",
    ms => "mm:ss",
    y => "y\N{U+5e74}",
    yM => "y\N{U+5e74}M\N{U+6708}",
    yMEd => "y/M/dE",
    yMM => "y\N{U+5e74}M\N{U+6708}",
    yMMM => "y\N{U+5e74}M\N{U+6708}",
    yMMMEd => "y\N{U+5e74}M\N{U+6708}d\N{U+65e5}E",
    yMMMM => "y\N{U+5e74}M\N{U+6708}",
    yMMMd => "y\N{U+5e74}M\N{U+6708}d\N{U+65e5}",
    yMd => "y/M/d",
    yQQQ => "y\N{U+5e74}QQQ",
    yQQQQ => "y\N{U+5e74}QQQQ",
    "yw-count-other" => "Y\N{U+5e74}\N{U+7b2c}w\N{U+4e2a}\N{U+661f}\N{U+671f}",
  },
  code => "yue-Hans-CN",
  date_format_full => "y\N{U+5e74}M\N{U+6708}d\N{U+65e5}EEEE",
  date_format_long => "y\N{U+5e74}M\N{U+6708}d\N{U+65e5}",
  date_format_medium => "y\N{U+5e74}M\N{U+6708}d\N{U+65e5}",
  date_format_short => "y/M/d",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "\N{U+5468}\N{U+4e00}",
    "\N{U+5468}\N{U+4e8c}",
    "\N{U+5468}\N{U+4e09}",
    "\N{U+5468}\N{U+56db}",
    "\N{U+5468}\N{U+4e94}",
    "\N{U+5468}\N{U+516d}",
    "\N{U+5468}\N{U+65e5}",
  ],
  day_format_narrow => [
    "\N{U+4e00}",
    "\N{U+4e8c}",
    "\N{U+4e09}",
    "\N{U+56db}",
    "\N{U+4e94}",
    "\N{U+516d}",
    "\N{U+65e5}",
  ],
  day_format_wide => [
    "\N{U+661f}\N{U+671f}\N{U+4e00}",
    "\N{U+661f}\N{U+671f}\N{U+4e8c}",
    "\N{U+661f}\N{U+671f}\N{U+4e09}",
    "\N{U+661f}\N{U+671f}\N{U+56db}",
    "\N{U+661f}\N{U+671f}\N{U+4e94}",
    "\N{U+661f}\N{U+671f}\N{U+516d}",
    "\N{U+661f}\N{U+671f}\N{U+65e5}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+5468}\N{U+4e00}",
    "\N{U+5468}\N{U+4e8c}",
    "\N{U+5468}\N{U+4e09}",
    "\N{U+5468}\N{U+56db}",
    "\N{U+5468}\N{U+4e94}",
    "\N{U+5468}\N{U+516d}",
    "\N{U+5468}\N{U+65e5}",
  ],
  day_stand_alone_narrow => [
    "\N{U+4e00}",
    "\N{U+4e8c}",
    "\N{U+4e09}",
    "\N{U+56db}",
    "\N{U+4e94}",
    "\N{U+516d}",
    "\N{U+65e5}",
  ],
  day_stand_alone_wide => [
    "\N{U+661f}\N{U+671f}\N{U+4e00}",
    "\N{U+661f}\N{U+671f}\N{U+4e8c}",
    "\N{U+661f}\N{U+671f}\N{U+4e09}",
    "\N{U+661f}\N{U+671f}\N{U+56db}",
    "\N{U+661f}\N{U+671f}\N{U+4e94}",
    "\N{U+661f}\N{U+671f}\N{U+516d}",
    "\N{U+661f}\N{U+671f}\N{U+65e5}",
  ],
  era_abbreviated => [
    "\N{U+897f}\N{U+5143}\N{U+524d}",
    "\N{U+897f}\N{U+5143}",
  ],
  era_narrow => [
    "\N{U+897f}\N{U+5143}\N{U+524d}",
    "\N{U+897f}\N{U+5143}",
  ],
  era_wide => [
    "\N{U+897f}\N{U+5143}\N{U+524d}",
    "\N{U+897f}\N{U+5143}",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Cantonese",
  month_format_abbreviated => [
    "1\N{U+6708}",
    "2\N{U+6708}",
    "3\N{U+6708}",
    "4\N{U+6708}",
    "5\N{U+6708}",
    "6\N{U+6708}",
    "7\N{U+6708}",
    "8\N{U+6708}",
    "9\N{U+6708}",
    "10\N{U+6708}",
    "11\N{U+6708}",
    "12\N{U+6708}",
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_format_wide => [
    "\N{U+4e00}\N{U+6708}",
    "\N{U+4e8c}\N{U+6708}",
    "\N{U+4e09}\N{U+6708}",
    "\N{U+56db}\N{U+6708}",
    "\N{U+4e94}\N{U+6708}",
    "\N{U+516d}\N{U+6708}",
    "\N{U+4e03}\N{U+6708}",
    "\N{U+516b}\N{U+6708}",
    "\N{U+4e5d}\N{U+6708}",
    "\N{U+5341}\N{U+6708}",
    "\N{U+5341}\N{U+4e00}\N{U+6708}",
    "\N{U+5341}\N{U+4e8c}\N{U+6708}",
  ],
  month_stand_alone_abbreviated => [
    "1\N{U+6708}",
    "2\N{U+6708}",
    "3\N{U+6708}",
    "4\N{U+6708}",
    "5\N{U+6708}",
    "6\N{U+6708}",
    "7\N{U+6708}",
    "8\N{U+6708}",
    "9\N{U+6708}",
    "10\N{U+6708}",
    "11\N{U+6708}",
    "12\N{U+6708}",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "\N{U+4e00}\N{U+6708}",
    "\N{U+4e8c}\N{U+6708}",
    "\N{U+4e09}\N{U+6708}",
    "\N{U+56db}\N{U+6708}",
    "\N{U+4e94}\N{U+6708}",
    "\N{U+516d}\N{U+6708}",
    "\N{U+4e03}\N{U+6708}",
    "\N{U+516b}\N{U+6708}",
    "\N{U+4e5d}\N{U+6708}",
    "\N{U+5341}\N{U+6708}",
    "\N{U+5341}\N{U+4e00}\N{U+6708}",
    "\N{U+5341}\N{U+4e8c}\N{U+6708}",
  ],
  name => "Cantonese China Simplified",
  native_language => "\N{U+7ca4}\N{U+8bed}",
  native_name => "\N{U+7ca4}\N{U+8bed} \N{U+4e2d}\N{U+534e}\N{U+4eba}\N{U+6c11}\N{U+5171}\N{U+548c}\N{U+56fd} \N{U+7b80}\N{U+4f53}",
  native_script => "\N{U+7b80}\N{U+4f53}",
  native_territory => "\N{U+4e2d}\N{U+534e}\N{U+4eba}\N{U+6c11}\N{U+5171}\N{U+548c}\N{U+56fd}",
  native_variant => undef,
  quarter_format_abbreviated => [
    "\N{U+7b2c}1\N{U+5b63}",
    "\N{U+7b2c}2\N{U+5b63}",
    "\N{U+7b2c}3\N{U+5b63}",
    "\N{U+7b2c}4\N{U+5b63}",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "\N{U+7b2c}1\N{U+5b63}",
    "\N{U+7b2c}2\N{U+5b63}",
    "\N{U+7b2c}3\N{U+5b63}",
    "\N{U+7b2c}4\N{U+5b63}",
  ],
  quarter_stand_alone_abbreviated => [
    "\N{U+7b2c}1\N{U+5b63}",
    "\N{U+7b2c}2\N{U+5b63}",
    "\N{U+7b2c}3\N{U+5b63}",
    "\N{U+7b2c}4\N{U+5b63}",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "\N{U+7b2c}1\N{U+5b63}",
    "\N{U+7b2c}2\N{U+5b63}",
    "\N{U+7b2c}3\N{U+5b63}",
    "\N{U+7b2c}4\N{U+5b63}",
  ],
  script => "Simplified",
  territory => "China",
  time_format_full => "zzzz HH:mm:ss",
  time_format_long => "z HH:mm:ss",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 40,
}
